=======
Authors
=======

This package is coded and maintained by Deltares, a not-for-profit, world-leading, and mission-driven Dutch knowledge institute for water and the subsurface. For more information, see https://www.deltares.nl/en/.

The main authors of this package are:

* Jan Kramer <jan.kramer@deltares.nl>
* Menno de Ridder <menno.deridder@deltares.nl>
* Ivo van der Werf <ivo.vanderwerf@deltares.nl>
* Joost den Bieman <joost.denbieman@deltares.nl>